## Code style

You can assume Python 3.12.
Use newest language features if possible
Consider using pattern matching, walrus operators and other new syntax features.
Adhere to pep8.

## Tests

Tests are written using PyTest. Dont put tests into a class.

## DocStrings

DocStrings are written in google-style.
Dont add the types to the "Args" section.
Only add a Return section if a value is returned and the meaning of the returned value
is not obvious.
You can use markdown admonitions with python-markdown syntax if neccessary (!!! info, !!! note, !!! warning).
You can use markdown tables and markdown lists if neccessary.
